{
  description = "Singer io SDK with strict types";
  inputs = {
    arch-lint = {
      url = "gitlab:dmurciaatfluid/arch_lint";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    nixpkgs.url = "github:nixos/nixpkgs?rev=0cd51a933d91078775b300cf0f29aa3495231aa2";
    nix_filter.url = "github:numtide/nix-filter";
    purity = {
      url = "gitlab:dmurciaatfluid/purity";
      inputs = {
        nixpkgs.follows = "nixpkgs";
        nix_filter.follows = "nix_filter";
      };
    };
  };
  outputs = {
    self,
    arch-lint,
    nixpkgs,
    nix_filter,
    purity,
  }: let
    metadata = (builtins.fromTOML (builtins.readFile ./pyproject.toml)).project;
    path_filter = nix_filter.outputs.lib;
    src = path_filter {
      root = self;
      include = [
        "mypy.ini"
        "pyproject.toml"
        (path_filter.inDirectory metadata.name)
        (path_filter.inDirectory "tests")
      ];
    };
    out = system: python_version:
      import ./build {
        inherit src python_version;
        nixpkgs =
          nixpkgs.legacyPackages."${system}"
          // {
            arch-lint = arch-lint.packages."${system}";
            purity = purity.packages."${system}";
          };
      };
    supported = ["python39" "python310" "python311"];
    python_outs = system:
      (builtins.listToAttrs (map (name: {
          inherit name;
          value = out system name;
        })
        supported))
      // {build_with_python = out system;};
    systems = [
      "aarch64-darwin"
      "aarch64-linux"
      "x86_64-darwin"
      "x86_64-linux"
    ];
    forAllSystems = nixpkgs.lib.genAttrs systems;
  in {
    packages = forAllSystems python_outs;
    defaultPackage = self.packages;
  };
}
